==> mutual_credit-6.0.0-beta1.tar.gz: mutual_credit/src/Plugin/views/field/Quant.php <==
<?php

namespace Drupal\mcapi\Plugin\views\field;

use Drupal\mcapi\Entity\Transaction;
use Drupal\mcapi\Entity\Wallet;
use Drupal\mcapi\Functions;
use Drupal\views\ResultRow;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;


/**
 * Field handler to provide running balance for a given transaction.
 *
 * @note reads from the transaction index table
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("mc_quant")
 *
 * @todo make the link on the formatted quant optional.
 */
class Quant extends FieldPluginBase {

  protected $config;

  /**
   * Constructs a Handler object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param ConfigFactoryInterface $config_factory
   *   The EntityTypeManager.
   */
  public function __construct($configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->config = $config_factory->get('mcapi.settings');
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration, $plugin_id, $plugin_definition,
      $container->get('config.factory')
    );
  }
    /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['link'] = ['default' => '1'];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['link'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Link to the currency metrics page'),
      '#default_value' => $this->options['link'],
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function render(ResultRow $values) {
    $entity = $this->getEntity($values);
    if ($entity instanceOf Wallet) {
      $quant = $entity->balance->getValue();
    }
    elseif ($entity instanceof Transaction) {
      // $transaction->quant isn't working via __get magic method
      $quant = $entity->entries[0]->quant;
    }
    return Functions::formatCurrency($quant, $this->options['link']);
  }


}

==> mutual_credit-6.1.0-beta1.tar.gz: mutual_credit/src/Plugin/views/field/Quant.php <==
<?php

namespace Drupal\mcapi\Plugin\views\field;

use Drupal\mcapi\Entity\Transaction;
use Drupal\mcapi\Functions;
use Drupal\views\ResultRow;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;


/**
 * Field handler to provide running balance for a given transaction.
 *
 * @note reads from the transaction index table
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("mc_quant")
 */
class Quant extends FieldPluginBase {

  protected $config;

  /**
   * Constructs a Handler object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param ConfigFactoryInterface $config_factory
   *   The EntityTypeManager.
   */
  public function __construct($configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->config = $config_factory->get('mcapi.settings');
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration, $plugin_id, $plugin_definition,
      $container->get('config.factory')
    );
  }
    /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['purpose'] = ['default' => 'balance'];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['purpose'] = [
      '#type' => 'radios',
      '#title' => t('Purpose of field'),
      '#options' => [
        'balance' => t('Format for wallet balance'),
        'amount' => t('Format for transaction amount')
      ],
      '#default_value' => $this->options['purpose']
    ];
    return $form;
  }

  /**
   * {@inheritDoc}
   * This field is used on wallets and transactions.
   */
  public function render(ResultRow $values) {
    $entity = $this->getEntity($values);
    if ($entity instanceof Transaction) {
      // $transaction->quant isn't working via __get magic method
      $quant = $entity->entries[0]->quant;
    }
    else {
      $quant = intval($this->getValue($values));
    }
    if ($this->options['purpose'] == 'balance') {
      $markup = Functions::formatBalance($quant);
    }
    else {
      $markup = Functions::formatCurrency($quant);
    }
    return $markup;
  }


}
